@@ -3,7 +3,7 @@ Amazon DynamoDB parameter retrieval and caching utility
 """
 
 
-from typing import Any, Dict, Optional
+from typing import Dict, Optional
 
 import boto3
 from boto3.dynamodb.conditions import Key
@@ -30,6 +30,8 @@ class DynamoDBProvider(BaseProvider):
         Complete url to reference local DynamoDB instance, e.g. http://localhost:8080
     config: botocore.config.Config, optional
         Botocore configuration to pass during client initialization
+    boto3_session : boto3.session.Session, optional
+            Boto3 session to use for AWS API communication
 
     Example
     -------
@@ -141,11 +143,6 @@ class DynamoDBProvider(BaseProvider):
         c   Parameter value c
     """
 
-    table: Any = None
-    key_attr = None
-    sort_attr = None
-    value_attr = None
-
     def __init__(
         self,
         table_name: str,
@@ -154,13 +151,16 @@ class DynamoDBProvider(BaseProvider):
         value_attr: str = "value",
         endpoint_url: Optional[str] = None,
         config: Optional[Config] = None,
+        boto3_session: Optional[boto3.session.Session] = None,
     ):
         """
         Initialize the DynamoDB client
         """
 
         config = config or Config()
-        self.table = boto3.resource("dynamodb", endpoint_url=endpoint_url, config=config).Table(table_name)
+        session = boto3_session or boto3.session.Session()
+
+        self.table = session.resource("dynamodb", endpoint_url=endpoint_url, config=config).Table(table_name)
 
         self.key_attr = key_attr
         self.sort_attr = sort_attr
